import 'package:flutter/widgets.dart';

import '../clx_verification_code.dart';

class CLXPageCodeManageView extends StatelessWidget {
  const CLXPageCodeManageView({
    super.key,
    required this.loigc,
    required this.config,
  });

  /// 页面状态变化处理控制器
  final CLXCodeManageLogic loigc;

  /// 是否隐藏输入内容
  final PageCodeManageConfig config;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: config.margin,
      padding: config.padding,
      decoration: config.decoration,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          GetBuilder(
            init: loigc,
            builder: (controller) {
              return CodeInputView(
                controller: loigc.codeInoutCtrl,
                focusNode: loigc.codeInoutFocus,
                obscureText: config.obscureText,
                maxLength: loigc.maxLength,
                inputRectBg: config.inputRectBg,
                runSpance: config.runSpance,
                radius: config.radius,
              );
            },
          ),
          Obx(
            () => Visibility(
              visible: loigc.verifyCodeError.value.isNotEmpty,
              child: Column(
                children: [
                  const SizedBox(height: 5),
                  Text(
                    loigc.verifyCodeError.value,
                    style: config.errorStyle,
                  ),
                ],
              ),
            ),
          ),
          Obx(
            () => Visibility(
              visible: loigc.isShowTip.value,
              child: Column(
                children: [
                  /// 展示重新发送验证码按钮以及获取语音验证码按钮
                  if (loigc.codeSendType.value ==
                      CodeSendType.notReceiveSmsCode)
                    NoReceiveSmsView(
                      tipsStyle: config.tipsStyle,
                      reSendStyle: config.reSendStyle,
                      voiceSendStyle: config.voiceSendStyle,
                      isSmallWindow: false,
                      sendSmsCode: loigc.sendSmsCode,
                      sendVoiceCode: loigc.sendVoiceCode,
                    ),

                  /// 展示没有收到二次发送的验证码的提示
                  if (loigc.codeSendType.value ==
                      CodeSendType.notReceiveResendSmsCode)
                    NoReceiveResendSmsView(
                      tipsStyle: config.tipsStyle,
                      reSendStyle: config.reSendStyle,
                      sendVoiceCode: loigc.sendVoiceCode,
                    ),

                  /// 展示没有收到首次发送的语音验证码的提示
                  if (loigc.codeSendType.value ==
                          CodeSendType.notReceiveVoiceCode ||
                      loigc.codeSendType.value ==
                          CodeSendType.notReceiveResendVoiceCode)
                    NoReceiveVoiceView(
                      tipsStyle: config.tipsStyle,
                      reSendStyle: config.reSendStyle,
                      contactStyle: config.contactStyle,
                      isSmallWindow: false,
                      sendVoiceCode: loigc.sendVoiceCode,
                      contactService: loigc.contactService,
                      isShowContact: loigc.codeSendType.value ==
                          CodeSendType.notReceiveResendVoiceCode,
                    ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}
